@@ -340,7 +340,7 @@ CK_RV
 load_token_data()
 {
    FILE        * fp;
-   CK_BYTE     fname[2048];
+   CK_BYTE     fname[PATH_MAX];
    TOKEN_DATA    td;
    CK_RV         rc;
 
@@ -412,7 +412,7 @@ save_token_data()
    FILE       *fp;
    TOKEN_DATA  td;
    CK_RV       rc;
-   CK_BYTE     fname[2048];
+   CK_BYTE     fname[PATH_MAX];
 
 
    sprintf((char *)fname,"%s/%s",pk_dir, PK_LITE_NV);
@@ -455,7 +455,7 @@ save_token_object( OBJECT *obj )
    FILE      * fp = NULL;
    CK_BYTE     line[100];
    CK_RV       rc;
-   CK_BYTE     fname[2048];
+   CK_BYTE     fname[PATH_MAX];
 
    if (object_is_private(obj) == TRUE)
       rc = save_private_token_object( obj );
@@ -513,7 +513,7 @@ save_public_token_object( OBJECT *obj )
 {
    FILE       * fp       = NULL;
    CK_BYTE    * cleartxt = NULL;
-   CK_BYTE      fname[2048];
+   CK_BYTE      fname[PATH_MAX];
    CK_ULONG     cleartxt_len;
    CK_BBOOL     flag = FALSE;
    CK_RV        rc;
@@ -698,7 +698,7 @@ load_public_token_objects( void )
 {
    FILE     *fp1 = NULL, *fp2 = NULL;
    CK_BYTE  *buf = NULL;
-   CK_BYTE   tmp[2048], fname[2048],iname[2048];
+   CK_BYTE   tmp[PATH_MAX], fname[PATH_MAX], iname[PATH_MAX];
    CK_BBOOL  priv;
    CK_ULONG_32  size;
 
@@ -761,7 +761,7 @@ load_private_token_objects( void )
 {
    FILE     *fp1 = NULL, *fp2 = NULL;
    CK_BYTE  *buf = NULL;
-   CK_BYTE   tmp[2048], fname[2048],iname[2048];
+   CK_BYTE   tmp[PATH_MAX], fname[PATH_MAX], iname[PATH_MAX];
    CK_BBOOL  priv;
    CK_ULONG_32  size;
    CK_RV     rc;
@@ -952,7 +952,7 @@ load_masterkey_so( void )
    MASTER_KEY_FILE_T    mk;
    CK_ULONG             cipher_len, clear_len;
    CK_RV                rc;
-   CK_BYTE              fname[2048];
+   CK_BYTE              fname[PATH_MAX];
 
 
    sprintf((char *)fname,"%s/MK_SO",pk_dir);
@@ -1048,7 +1048,7 @@ load_masterkey_user( void )
    MASTER_KEY_FILE_T    mk;
    CK_ULONG             cipher_len, clear_len;
    CK_RV                rc;
-   CK_BYTE              fname[2048];
+   CK_BYTE              fname[PATH_MAX];
 
 
    sprintf((char *)fname,"%s/MK_USER",pk_dir);
@@ -1143,7 +1143,7 @@ save_masterkey_so( void )
    MASTER_KEY_FILE_T  mk;
    CK_ULONG           cleartxt_len, ciphertxt_len, padded_len;
    CK_RV              rc;
-   CK_BYTE            fname[2048];
+   CK_BYTE            fname[PATH_MAX];
 
 
    memcpy( mk.key, master_key, 3 * DES_KEY_SIZE);
@@ -1226,7 +1226,7 @@ save_masterkey_user( void )
    MASTER_KEY_FILE_T  mk;
    CK_ULONG           cleartxt_len, ciphertxt_len, padded_len;
    CK_RV              rc;
-   CK_BYTE            fname[2048];
+   CK_BYTE            fname[PATH_MAX];
 
    memcpy( mk.key, master_key, 3 * DES_KEY_SIZE);
 
@@ -1305,7 +1305,7 @@ reload_token_object( OBJECT *obj )
 {
    FILE     * fp  = NULL;
    CK_BYTE  * buf = NULL;
-   CK_BYTE    fname[2048];
+   CK_BYTE    fname[PATH_MAX];
    CK_BBOOL   priv;
    CK_ULONG_32   size;
    CK_ULONG   size_64;
@@ -1371,7 +1371,7 @@ delete_token_object( OBJECT *obj )
 {
    FILE      *fp1, *fp2;
    CK_BYTE    line[100];
-   CK_BYTE    objidx[2048], idxtmp[2048],fname[2048];
+   CK_BYTE    objidx[PATH_MAX], idxtmp[PATH_MAX], fname[PATH_MAX];
 
 
    sprintf((char *)objidx,"%s/%s/%s",pk_dir, PK_LITE_OBJ_DIR,PK_LITE_OBJ_IDX);
