@@ -294,7 +294,6 @@
 // Verify manager routines
 //
 
-//#include <windows.h>
 #include <pthread.h>
 #include <string.h>            // for memcmp() et al
 #include <stdlib.h>
@@ -493,6 +492,7 @@ verify_mgr_init( SESSION             * sess,
       case CKM_MD2_HMAC:
       case CKM_MD5_HMAC:
       case CKM_SHA_1_HMAC:
+      case CKM_SHA256_HMAC:
          {
             if (mech->ulParameterLen != 0){
                st_err_log(29, __FILE__, __LINE__);
@@ -521,6 +521,7 @@ verify_mgr_init( SESSION             * sess,
       case CKM_MD2_HMAC_GENERAL:
       case CKM_MD5_HMAC_GENERAL:
       case CKM_SHA_1_HMAC_GENERAL:
+      case CKM_SHA256_HMAC_GENERAL:
          {
             CK_MAC_GENERAL_PARAMS *param = (CK_MAC_GENERAL_PARAMS *)mech->pParameter;
 
@@ -540,6 +541,10 @@ verify_mgr_init( SESSION             * sess,
                st_err_log(29, __FILE__, __LINE__);
                return CKR_MECHANISM_PARAM_INVALID;
             }
+            if ((mech->mechanism == CKM_SHA256_HMAC_GENERAL) && (*param > 32)){
+               st_err_log(29, __FILE__, __LINE__);
+               return CKR_MECHANISM_PARAM_INVALID;
+            }
             rc = template_attribute_find( key_obj->template, CKA_KEY_TYPE, &attr );
             if (rc == FALSE){
                st_err_log(20, __FILE__, __LINE__);
@@ -746,6 +751,12 @@ verify_mgr_verify( SESSION             * sess,
                                   in_data,   in_data_len,
                                   signature, sig_len );
 
+      case CKM_SHA256_HMAC:
+      case CKM_SHA256_HMAC_GENERAL:
+         return sha2_hmac_verify( sess,      ctx,
+                                  in_data,   in_data_len,
+                                  signature, sig_len );
+
       case CKM_SSL3_MD5_MAC:
       case CKM_SSL3_SHA1_MAC:
          return ssl3_mac_verify( sess,      ctx,
