@@ -367,6 +367,7 @@ main(int argc, char *argv[]){
                slot = NULL;    // The PKCS slot number
 
    int c,                      // To store passed in options
+       newpinlen, newpin2len,
        errflag = 0;            // Error Flag
 
    /* Open the Message Catalog */
@@ -518,10 +519,12 @@ main(int argc, char *argv[]){
          printf(PKCSINIT_MSG(NEWUSER, "Enter the new user PIN: "));
          fflush(stdout);
          get_pin(&newpin);
+	 newpinlen = strlen(newpin);
          printf(PKCSINIT_MSG(VNEWUSER, "Re-enter the new user PIN: "));
          fflush(stdout);
          get_pin(&newpin2);
-         if (! memcmp(newpin, newpin2, strlen((char *)newpin)) == 0) {
+	 newpin2len = strlen(newpin2);
+         if (newpinlen != newpin2len || memcmp(newpin, newpin2, strlen((char *)newpin)) != 0) {
             printf(PKCSINIT_MSG(PINMISMATCH, "New PINs do not match.\n"));
             fflush(stdout);
             exit(CKR_PIN_INVALID);
@@ -542,10 +545,12 @@ main(int argc, char *argv[]){
          printf(PKCSINIT_MSG(NEWSO, "Enter the new SO PIN: "));
          fflush(stdout);
          get_pin(&newpin);
+	 newpinlen = strlen(newpin);
          printf(PKCSINIT_MSG(VNEWSO, "Re-enter the new SO PIN: "));
          fflush(stdout);
          get_pin(&newpin2);
-         if (! memcmp(newpin, newpin2, strlen((char *)newpin)) == 0) {
+	 newpin2len = strlen(newpin2);
+         if (newpinlen != newpin2len || memcmp(newpin, newpin2, strlen((char *)newpin)) != 0) {
             printf(PKCSINIT_MSG(PINMISMATCH, "New PINs do not match.\n"));
             fflush(stdout);
             exit(CKR_PIN_INVALID);
@@ -566,10 +571,12 @@ main(int argc, char *argv[]){
          printf(PKCSINIT_MSG(NEWUSER, "Enter the new user PIN: "));
          fflush(stdout);
          get_pin(&newpin);
+	 newpinlen = strlen(newpin);
          printf(PKCSINIT_MSG(VNEWUSER, "Re-enter the new user PIN: "));
          fflush(stdout);
          get_pin(&newpin2);
-         if (! memcmp(newpin, newpin2, strlen((char *)newpin)) == 0) {
+	 newpin2len = strlen(newpin2);
+         if (newpinlen != newpin2len || memcmp(newpin, newpin2, strlen((char *)newpin)) != 0) {
             printf(PKCSINIT_MSG(PINMISMATCH, "New PINs do not match.\n"));
             fflush(stdout);
             exit(CKR_PIN_INVALID);
@@ -579,7 +586,7 @@ main(int argc, char *argv[]){
    }
 
    /* We are done, detach from shared memory, and free the memory we may have
-    * allocated.  In the case of PIN's we bzero them to ensure that they are not
+    * allocated.  In the case of PIN's we memset them to ensure that they are not
     * left around in system memory*/
 
 done:
@@ -589,27 +596,32 @@ done:
 #endif
 
    if (sopin) {
-     bzero (sopin, strlen((char *)sopin));
+     memset(sopin, 0, strlen((char *)sopin));
      free (sopin);
    }
 
    if (pin) {
-      bzero (pin, strlen((char *)pin));
+      memset(pin, 0, strlen((char *)pin));
       free (pin);
    }
 
    if (newpin) {
-      bzero (newpin, strlen((char *)newpin));
+      memset(newpin, 0, strlen((char *)newpin));
       free (newpin);
    }
 
+   if (newpin2) {
+      memset(newpin2, 0, strlen((char *)newpin2));
+      free (newpin2);
+   }
+
    return rc;
 
 }
 
 void
 get_pin(CK_CHAR ** pin){
-   int  size = PIN_SIZE, count = 0;
+   int  count = 0;
    char buff[PIN_SIZE] = { 0 }, c = 0;
 
    /* Turn off echoing to the terminal when getting the password */
@@ -734,7 +746,6 @@ display_pkcs11_info(void){
 
 CK_RV
 get_slot_list(int cond, CK_CHAR_PTR slot){
-   int                   lcv;                  // Loop control variable
    CK_RV                 rc;                   // Return Code
    CK_SLOT_ID_PTR        TempSlotList = NULL;  // Temporary Slot List
 
@@ -1175,13 +1186,9 @@ init(void){
     * error */
    /* The host machine should have the right library in the
     * LD_LIBRARY_PATH */
-/*   if (sizeof(CK_ULONG) == 4) 
-      dllPtr = dlopen("/usr/lib/pkcs11/PKCS11_API.so", RTLD_NOW);
-   else
-   dllPtr = dlopen("/usr/lib/pkcs11/PKCS11_API.so64", RTLD_NOW); */
    dllPtr = dlopen("libopencryptoki.so", RTLD_NOW);
    if (!dllPtr) {
-      printf(PKCSINIT_MSG(LOADERROR, "Error loading PKCS#11 library: 0x%X\n"), rc);
+      printf(PKCSINIT_MSG(LOADERROR, "Error loading PKCS#11 library\n"));
       printf(PKCSINIT_MSG(LOADERROR, "dlopen error: %s\n"), dlerror());
       fflush(stdout);
       return -1;
